/* C utils

*/


#include <stdio.h>
#include <stdlib.h>  /* malloc, EXIT_FAILURE */
#include <sys/time.h> /* getrusage */
#include <sys/resource.h>


void panic(char *s)
{
  fflush(NULL);
  fprintf(stderr, "\nPANIC: ");
  perror(s);
  fflush(stderr);
  exit(EXIT_FAILURE);
}


void *safe_malloc(size_t size, char *error_msg)
{
  void *ptr = malloc(size);

  if (! ptr) {
    panic(error_msg);
  }
  return ptr;
}


/* Gets the CPU time in seconds. */
double get_current_seconds(void)
{
    double sec, usec;
    struct rusage ru;

    if (getrusage(RUSAGE_SELF, &ru) != 0) {
	perror("getrusage failed");
	exit(EXIT_FAILURE);
    }

    sec = ru.ru_utime.tv_sec + ru.ru_stime.tv_sec;
    usec = ru.ru_utime.tv_usec + ru.ru_stime.tv_usec;

    return sec + (usec / 1000000);
}


/* EOF */
